# pem: Easy PEM file parsing in Python.

Release **{sub-ref}`release`** ({doc}`What's new? <changelog>`)

```{include} ../README.md
:start-after: teaser-begin -->
:end-before: "## Project Information"
```

## User's Guide

```{toctree}
:maxdepth: 1

core
twisted
api
```


## Project Information

```{include} ../README.md
:start-after: "## Project Information"
```


## Indices and tables

- {ref}`genindex`
- {ref}`search`

```{toctree}
:hidden:

changelog
```
